@@ -2,11 +2,15 @@ package agent
 
 import (
 	"fmt"
+	"os"
+	"os/exec"
 	"path"
+	"path/filepath"
 	"regexp"
 	"strconv"
 	"strings"
 
+	"github.com/pkg/errors"
 	log "github.com/sirupsen/logrus"
 
 	storkutil "isc.org/stork/util"
@@ -25,14 +29,93 @@ type Bind9State struct {
 	Daemon  Bind9Daemon
 }
 
+// It holds common and BIND 9 specifc runtime information.
+type Bind9App struct {
+	BaseApp
+	RndcClient *RndcClient // to communicate with BIND 9 via rndc
+}
+
+// Get base information about BIND 9 app.
+func (ba *Bind9App) GetBaseApp() *BaseApp {
+	return &ba.BaseApp
+}
+
+// Detect allowed logs provided by BIND 9.
+// TODO: currently it is not implemented and not used,
+// it returns always empty list and no error.
+func (ba *Bind9App) DetectAllowedLogs() ([]string, error) {
+	return nil, nil
+}
+
+// List of BIND 9 executables used durint app detection.
+const (
+	namedCheckconfExec = "named-checkconf"
+	rndcExec           = "rndc"
+)
+
+// rndc key file name.
+const RndcKeyFile = "rndc.key"
+
+// Default ports for rndc and stats channel.
 const (
 	RndcDefaultPort         = 953
 	StatsChannelDefaultPort = 80
 )
 
-const defaultNamedConfFile = "/etc/bind/named.conf"
+// Object for interacting with named using rndc.
+type RndcClient struct {
+	execute     CommandExecutor
+	BaseCommand []string
+}
 
-const namedCheckconf = "named-checkconf"
+// CommandExecutor takes an array of strings, with the first element of the
+// array being the program to call, followed by its arguments.  It returns
+// the command output, and possibly an error (for example if running the
+// command failed).
+type CommandExecutor func([]string) ([]byte, error)
+
+// Create an rndc client to communicate with BIND 9 named daemon.
+func NewRndcClient(ce CommandExecutor) *RndcClient {
+	rndcClient := &RndcClient{
+		execute: ce,
+	}
+	return rndcClient
+}
+
+// Determine rndc details in the system.
+// It find rndc executable and prepare base command with all necessary
+// parameters including rndc secret key.
+func (rc *RndcClient) DetermineDetails(baseNamedDir, bind9ConfDir string, ctrlAddress string, ctrlPort int64, ctrlKey string) error {
+	rndcPath, err := determineBinPath(baseNamedDir, rndcExec)
+	if err != nil {
+		return err
+	}
+
+	cmd := []string{rndcPath, "-s", ctrlAddress, "-p", fmt.Sprintf("%d", ctrlPort)}
+
+	if len(ctrlKey) > 0 {
+		cmd = append(cmd, "-y")
+		cmd = append(cmd, ctrlKey)
+	} else {
+		keyPath := path.Join(bind9ConfDir, RndcKeyFile)
+		if _, err := os.Stat(keyPath); err == nil {
+			cmd = append(cmd, "-k")
+			cmd = append(cmd, keyPath)
+		} else {
+			return errors.New("cannot determine rndc key")
+		}
+	}
+	rc.BaseCommand = cmd
+	return nil
+}
+
+// Send command to named using rndc executable.
+func (rc *RndcClient) SendCommand(command []string) (output []byte, err error) {
+	rndcCommand := append(rc.BaseCommand, command...)
+	log.Debugf("rndc: %+v", rndcCommand)
+
+	return rc.execute(rndcCommand)
+}
 
 // getRndcKey looks for the key with a given `name` in `contents`.
 //
@@ -227,7 +310,35 @@ func getStatisticsChannelFromBind9Config(text string) (statsAddress string, stat
 	return statsAddress, statsPort, statsKey
 }
 
-func detectBind9App(match []string, cwd string, cmdr storkutil.Commander) (bind9App *App) {
+// Determine executable using base named directory or system default paths.
+func determineBinPath(baseNamedDir, executable string) (string, error) {
+	// look for executable in base named directory and sbin or bin subdirectory
+	if baseNamedDir != "" {
+		for _, binDir := range []string{"sbin", "bin"} {
+			fullPath := path.Join(baseNamedDir, binDir, executable)
+			if _, err := os.Stat(fullPath); err == nil {
+				return fullPath, nil
+			}
+		}
+	}
+
+	// not found so try to find generally in the system
+	fullPath, err := exec.LookPath(executable)
+	if err != nil {
+		return "", errors.Errorf("cannot determine location of %s", executable)
+	}
+	return fullPath, nil
+}
+
+// Get potential locations of named.conf.
+func getPotentialNamedConfLocations() []string {
+	return []string{
+		"/etc/bind/named.conf",
+		"/etc/opt/isc/isc-bind/named.conf",
+	}
+}
+
+func detectBind9App(match []string, cwd string, cmdr storkutil.Commander) App {
 	if len(match) < 3 {
 		log.Warnf("problem with parsing BIND 9 cmdline: %s", match[0])
 		return nil
@@ -249,20 +360,37 @@ func detectBind9App(match []string, cwd string, cmdr storkutil.Commander) (bind9
 		}
 	} else {
 		// config path not found in cmdline params so try to guess its location
-		bind9ConfPath = defaultNamedConfFile
+		for _, f := range getPotentialNamedConfLocations() {
+			if _, err := os.Stat(f); err == nil {
+				bind9ConfPath = f
+				break
+			}
+		}
 	}
 
 	// no config file so nothing to do
 	if bind9ConfPath == "" {
+		log.Warnf("cannot find config file for BIND 9")
 		return nil
 	}
 
-	// run named-checkconf on main config file and get preprocessed content of whole config
-	prog := namedCheckconf
+	// determine config directory
+	bind9ConfDir := path.Dir(bind9ConfPath)
+
+	// determine base named directory
+	baseNamedDir := ""
 	if namedDir != "" {
-		prog = path.Join(namedDir, prog)
+		// remove sbin or bin at the end
+		baseNamedDir, _ = filepath.Split(strings.TrimRight(namedDir, "/"))
 	}
-	out, err := cmdr.Output(prog, "-p", bind9ConfPath)
+
+	// run named-checkconf on main config file and get preprocessed content of whole config
+	namedCheckconfPath, err := determineBinPath(baseNamedDir, namedCheckconfExec)
+	if err != nil {
+		log.Warnf("cannot find BIND 9 %s: %s", namedCheckconfExec, err)
+		return nil
+	}
+	out, err := cmdr.Output(namedCheckconfPath, "-p", bind9ConfPath)
 	if err != nil {
 		log.Warnf("cannot parse BIND 9 config file %s: %+v; %s", bind9ConfPath, err, out)
 		return nil
@@ -270,22 +398,21 @@ func detectBind9App(match []string, cwd string, cmdr storkutil.Commander) (bind9
 	cfgText := string(out)
 
 	// look for control address in config
-	address, port, key := getCtrlAddressFromBind9Config(cfgText)
-	if port == 0 || len(address) == 0 {
+	ctrlAddress, ctrlPort, ctrlKey := getCtrlAddressFromBind9Config(cfgText)
+	if ctrlPort == 0 || len(ctrlAddress) == 0 {
 		log.Warnf("found BIND 9 config file (%s) but cannot parse controls clause", bind9ConfPath)
 		return nil
 	}
 	accessPoints := []AccessPoint{
 		{
 			Type:    AccessPointControl,
-			Address: address,
-			Port:    port,
-			Key:     key,
+			Address: ctrlAddress,
+			Port:    ctrlPort,
 		},
 	}
 
 	// look for statistics channel address in config
-	address, port, key = getStatisticsChannelFromBind9Config(cfgText)
+	address, port, key := getStatisticsChannelFromBind9Config(cfgText)
 	if port > 0 && len(address) != 0 {
 		accessPoints = append(accessPoints, AccessPoint{
 			Type:    AccessPointStatistics,
@@ -297,8 +424,33 @@ func detectBind9App(match []string, cwd string, cmdr storkutil.Commander) (bind9
 		log.Warnf("cannot parse BIND 9 statistics-channels clause")
 	}
 
-	return &App{
-		Type:         AppTypeBind9,
-		AccessPoints: accessPoints,
+	// rndc is the command to interface with BIND 9.
+	rndc := func(command []string) ([]byte, error) {
+		cmd := exec.Command(command[0], command[1:]...) //nolint:gosec
+		return cmd.Output()
 	}
+
+	// determine rndc details
+	rndcClient := NewRndcClient(rndc)
+	err = rndcClient.DetermineDetails(baseNamedDir, bind9ConfDir, ctrlAddress, ctrlPort, ctrlKey)
+	if err != nil {
+		log.Warnf("cannot determine BIND 9 rndc details: %s", err)
+		return nil
+	}
+
+	// prepare final BIND 9 app
+	bind9App := &Bind9App{
+		BaseApp: BaseApp{
+			Type:         AppTypeBind9,
+			AccessPoints: accessPoints,
+		},
+		RndcClient: rndcClient,
+	}
+
+	return bind9App
+}
+
+// Send a command to named using rndc client.
+func (ba *Bind9App) sendCommand(command []string) (output []byte, err error) {
+	return ba.RndcClient.SendCommand(command)
 }
