@@ -7,6 +7,7 @@ import (
 	"io/ioutil"
 	"math/rand"
 	"net"
+	"os"
 
 	"github.com/go-pg/pg/v9"
 	"github.com/pkg/errors"
@@ -15,6 +16,14 @@ import (
 	dbmodel "isc.org/stork/server/database/model"
 )
 
+const (
+	SecretTypeCACert   = "CA cert"
+	SecretTypeCAKey    = "CA key"
+	SecretTypeSrvKey   = "server key"
+	SecretTypeSrvCert  = "server cert"
+	SecretTypeSrvToken = "server token"
+)
+
 // Generate server token and store it in database.  It is used during
 // manual agent registration.  This function uses random numbers
 // generator so it is expected that it is seeded prior its use.
@@ -198,15 +207,15 @@ func ExportSecret(db *pg.DB, object string, filename string) error {
 	var objDisplayName string
 	switch object {
 	case dbmodel.SecretCAKey:
-		objDisplayName = "CA key"
+		objDisplayName = SecretTypeCAKey
 	case dbmodel.SecretCACert:
-		objDisplayName = "CA cert"
+		objDisplayName = SecretTypeCACert
 	case dbmodel.SecretServerKey:
-		objDisplayName = "server key"
+		objDisplayName = SecretTypeSrvKey
 	case dbmodel.SecretServerCert:
-		objDisplayName = "server cert"
+		objDisplayName = SecretTypeSrvCert
 	case dbmodel.SecretServerToken:
-		objDisplayName = "server token"
+		objDisplayName = SecretTypeSrvToken
 	default:
 		return errors.Errorf("requested unknown object '%s'", object)
 	}
@@ -227,3 +236,74 @@ func ExportSecret(db *pg.DB, object string, filename string) error {
 
 	return nil
 }
+
+// Import a secret e.g. certificate or server token from stdin or from indicated file.
+func ImportSecret(db *pg.DB, object string, filename string) error {
+	var objDisplayName string
+	switch object {
+	case dbmodel.SecretCAKey:
+		objDisplayName = SecretTypeCAKey
+	case dbmodel.SecretCACert:
+		objDisplayName = SecretTypeCACert
+	case dbmodel.SecretServerKey:
+		objDisplayName = SecretTypeSrvKey
+	case dbmodel.SecretServerCert:
+		objDisplayName = SecretTypeSrvCert
+	case dbmodel.SecretServerToken:
+		objDisplayName = SecretTypeSrvToken
+	default:
+		return errors.Errorf("indicated unknown object '%s'", object)
+	}
+
+	var content []byte
+	var err error
+	if filename != "" {
+		content, err = ioutil.ReadFile(filename)
+		if err != nil {
+			return err
+		}
+		log.Printf("%s loaded from %s file, length %d", objDisplayName, filename, len(content))
+	} else {
+		log.Printf("reading %s from stdin", objDisplayName)
+		content, err = ioutil.ReadAll(os.Stdin)
+		if err != nil {
+			return err
+		}
+		log.Printf("%s read from stdin, length %d", objDisplayName, len(content))
+	}
+
+	// Now we need to conduct verification if the content is sane.
+	switch object {
+	case dbmodel.SecretCAKey:
+		objDisplayName = SecretTypeCAKey
+		_, err = pki.ParsePrivateKey(content)
+	case dbmodel.SecretCACert:
+		objDisplayName = SecretTypeCACert
+		_, err = pki.ParseCert(content)
+	case dbmodel.SecretServerKey:
+		objDisplayName = SecretTypeSrvKey
+		_, err = pki.ParsePrivateKey(content)
+	case dbmodel.SecretServerCert:
+		objDisplayName = SecretTypeSrvCert
+		_, err = pki.ParseCert(content)
+	case dbmodel.SecretServerToken:
+		objDisplayName = SecretTypeSrvToken
+		if len(content) != 32 {
+			return errors.Errorf("server token has to be exactly 32 bytes long, provided is %d bytes", len(content))
+		}
+	default:
+		return errors.Errorf("unsupported object: %s", object)
+	}
+
+	if err != nil {
+		return errors.Wrapf(err, "problem parsing the %s", objDisplayName)
+	}
+
+	// The value looks reasonable. Let's set it in the DB
+	err = dbmodel.SetSecret(db, object, content)
+	if err != nil {
+		return errors.Wrapf(err, "problem with setting '%s' in database", objDisplayName)
+	}
+
+	return nil
+}
