@@ -1,4 +1,4 @@
-import { async, ComponentFixture, TestBed } from '@angular/core/testing'
+import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 import { BreadcrumbsComponent } from './breadcrumbs.component'
 import { RouterTestingModule } from '@angular/router/testing'
 
@@ -6,12 +6,14 @@ describe('BreadcrumbsComponent', () => {
     let component: BreadcrumbsComponent
     let fixture: ComponentFixture<BreadcrumbsComponent>
 
-    beforeEach(async(() => {
-        TestBed.configureTestingModule({
-            imports: [RouterTestingModule],
-            declarations: [BreadcrumbsComponent],
-        }).compileComponents()
-    }))
+    beforeEach(
+        waitForAsync(() => {
+            TestBed.configureTestingModule({
+                imports: [RouterTestingModule],
+                declarations: [BreadcrumbsComponent],
+            }).compileComponents()
+        })
+    )
 
     beforeEach(() => {
         fixture = TestBed.createComponent(BreadcrumbsComponent)
