@@ -1,5 +1,5 @@
 import { HttpClientTestingModule } from '@angular/common/http/testing'
-import { async, ComponentFixture, TestBed } from '@angular/core/testing'
+import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 import { ActivatedRoute, Router } from '@angular/router'
 import { MessageService } from 'primeng/api'
 
@@ -41,26 +41,28 @@ describe('EventsPanelComponent', () => {
         expect(params.get(name)).toBe(value)
     }
 
-    beforeEach(async(() => {
-        TestBed.configureTestingModule({
-            providers: [
-                EventsService,
-                UsersService,
-                ServicesService,
-                MessageService,
-                {
-                    provide: Router,
-                    useValue: {},
-                },
-                {
-                    provide: ActivatedRoute,
-                    useValue: {},
-                },
-            ],
-            imports: [HttpClientTestingModule],
-            declarations: [EventsPanelComponent],
-        }).compileComponents()
-    }))
+    beforeEach(
+        waitForAsync(() => {
+            TestBed.configureTestingModule({
+                providers: [
+                    EventsService,
+                    UsersService,
+                    ServicesService,
+                    MessageService,
+                    {
+                        provide: Router,
+                        useValue: {},
+                    },
+                    {
+                        provide: ActivatedRoute,
+                        useValue: {},
+                    },
+                ],
+                imports: [HttpClientTestingModule],
+                declarations: [EventsPanelComponent],
+            }).compileComponents()
+        })
+    )
 
     beforeEach(() => {
         fixture = TestBed.createComponent(EventsPanelComponent)
