@@ -28,7 +28,9 @@ class MockParamMap {
 describe('KeaDaemonConfigurationPageComponent', () => {
     let component: KeaDaemonConfigurationPageComponent
     let fixture: ComponentFixture<KeaDaemonConfigurationPageComponent>
-    let service: ServerDataService
+    let dataService: ServerDataService
+    let userService: UsersService
+    let authService: AuthService
 
     beforeEach(
         waitForAsync(() => {
@@ -54,7 +56,9 @@ describe('KeaDaemonConfigurationPageComponent', () => {
                     UsersService,
                     {
                         provide: Router,
-                        useValue: {},
+                        useValue: {
+                            navigate: () => {},
+                        },
                     },
                     {
                         provide: ActivatedRoute,
@@ -64,15 +68,11 @@ describe('KeaDaemonConfigurationPageComponent', () => {
                             paramMap: of(convertToParamMap({ appId: '1', daemonId: '2' })),
                         },
                     },
-                    {
-                        provide: AuthService,
-                        useValue: {
-                            currentUser: of({}),
-                        },
-                    },
                 ],
             })
-            service = TestBed.inject(ServerDataService)
+            dataService = TestBed.inject(ServerDataService)
+            userService = TestBed.inject(UsersService)
+            authService = TestBed.inject(AuthService)
         })
     )
 
@@ -89,13 +89,35 @@ describe('KeaDaemonConfigurationPageComponent', () => {
                 ],
             },
         }
-        spyOn(service.servicesApi, 'getApp').and.returnValue(of(fakeResponse))
-        spyOn(service.servicesApi, 'getDaemonConfig').and.returnValues(
+        spyOn(dataService.servicesApi, 'getApp').and.returnValue(of(fakeResponse))
+        spyOn(dataService.servicesApi, 'getDaemonConfig').and.returnValues(
             of({} as any),
             of({ foo: 42 } as any),
+            of({ secret: 'SECRET', password: 'PASSWORD' } as any),
             throwError(new HttpErrorResponse({ status: 400 }))
         )
 
+        spyOn(userService, 'createSession').and.returnValues(
+            of({
+                id: 1,
+                login: 'foo',
+                email: 'foo@bar.baz',
+                name: 'foo',
+                lastname: 'bar',
+                groups: [],
+            } as any),
+            of({
+                id: 1,
+                login: 'foo',
+                email: 'foo@bar.baz',
+                name: 'foo',
+                lastname: 'bar',
+                groups: [1],
+            } as any)
+        )
+
+        authService.login('foo', 'bar', 'baz')
+
         fixture = TestBed.createComponent(KeaDaemonConfigurationPageComponent)
         component = fixture.componentInstance
         fixture.detectChanges()
@@ -106,16 +128,13 @@ describe('KeaDaemonConfigurationPageComponent', () => {
     })
 
     it('should toggle expand nodes', () => {
-        expect(component.autoExpandNodeCount).toBe(0)
-        expect(component.currentAction).toBe('expand')
+        expect(component.autoExpand).toBe('none')
         component.onClickToggleNodes()
 
-        expect(component.autoExpandNodeCount).toBe(Number.MAX_SAFE_INTEGER)
-        expect(component.currentAction).toBe('collapse')
+        expect(component.autoExpand).toBe('all')
         component.onClickToggleNodes()
 
-        expect(component.autoExpandNodeCount).toBe(0)
-        expect(component.currentAction).toBe('expand')
+        expect(component.autoExpand).toBe('none')
     })
 
     it('should set filename for download file', async () => {
@@ -145,6 +164,10 @@ describe('KeaDaemonConfigurationPageComponent', () => {
         await fixture.whenStable()
         expect(component.failedFetch).toBeFalse()
 
+        component.onClickRefresh()
+        fixture.detectChanges()
+        await fixture.whenRenderingDone()
+
         component.onClickRefresh()
         fixture.detectChanges()
         await fixture.whenRenderingDone()
