@@ -1,4 +1,4 @@
-import { async, ComponentFixture, TestBed } from '@angular/core/testing'
+import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 import { By } from '@angular/platform-browser'
 
 import { FormsModule, ReactiveFormsModule } from '@angular/forms'
@@ -7,6 +7,8 @@ import { FieldsetModule } from 'primeng/fieldset'
 import { MessageService } from 'primeng/api'
 import { HttpClientTestingModule } from '@angular/common/http/testing'
 
+import { MessagesModule } from 'primeng/messages'
+
 import { SettingsPageComponent } from './settings-page.component'
 import { SettingsService } from '../backend/api/api'
 
@@ -14,19 +16,22 @@ describe('SettingsPageComponent', () => {
     let component: SettingsPageComponent
     let fixture: ComponentFixture<SettingsPageComponent>
 
-    beforeEach(async(() => {
-        TestBed.configureTestingModule({
-            imports: [
-                FormsModule,
-                ReactiveFormsModule,
-                BrowserAnimationsModule,
-                FieldsetModule,
-                HttpClientTestingModule,
-            ],
-            declarations: [SettingsPageComponent],
-            providers: [SettingsService, MessageService],
-        }).compileComponents()
-    }))
+    beforeEach(
+        waitForAsync(() => {
+            TestBed.configureTestingModule({
+                imports: [
+                    FormsModule,
+                    ReactiveFormsModule,
+                    BrowserAnimationsModule,
+                    FieldsetModule,
+                    HttpClientTestingModule,
+                    MessagesModule,
+                ],
+                declarations: [SettingsPageComponent],
+                providers: [SettingsService, MessageService],
+            }).compileComponents()
+        })
+    )
 
     beforeEach(() => {
         fixture = TestBed.createComponent(SettingsPageComponent)
